@@ -18,13 +18,18 @@ y_ls = [math.sin(x) + random.random() * 0.5
 	for x in x_ls]
 
 # 分位点散布図の描画 [quantile_scatter]
-quantile_scatter.plot(
+data = quantile_scatter.plot(
 	x = x_ls,	# 横軸数値リスト
 	y = y_ls,	# 縦軸数値リスト
 	group_n = 20,	# 分割グループ数
-	ile_ls = [0.25, 0.5, 0.75]	# どこの分位点を出すか
+	ile_ls = [0.25, 0.5, 0.75],	# どこの分位点を出すか
+	mean = True,	# 平均も出力する
+	show = True,	# False指定でグラフを出力しない (データ集計のみ)
 )
 
+# debug
+sout(data)
+
 # 元データ
 from matplotlib import pyplot as plt
 plt.scatter(x_ls, y_ls)
